import React, { useState, useRef, useCallback, useEffect, useMemo } from 'react';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}

var Slider = function Slider(_ref) {
  var styles = _ref.styles,
    imageBlock = _ref.imageBlock,
    zoomIndex = _ref.zoomIndex,
    setData = _ref.setData,
    isAutoSlide = _ref.isAutoSlide,
    autoSlideDuration = _ref.autoSlideDuration;
  var _useState = useState(false),
    isAutoStart = _useState[0],
    isAutoStartSet = _useState[1];
  var started = useRef({
    started: false,
    timeout: null
  });
  var moveSlide = useCallback(function (key, isRestartTimer) {
    if (isRestartTimer === void 0) {
      isRestartTimer = true;
    }
    setData(function (preState) {
      var childLength = imageBlock.current.children.length;
      var value = preState.sliderIndex;
      if (key === 'next') {
        if (childLength - 1 === value) {
          value = 0;
        } else {
          value += 1;
        }
      } else {
        if (value === 0) {
          value = childLength - 1;
        } else {
          value -= 1;
        }
      }
      var obj = {
        sliderIndex: value
      };
      if (zoomIndex !== 0) obj.zoomIndex = 0;
      return _extends({}, preState, obj);
    });
    if (isRestartTimer) {
      startAutoSliding();
    }
  }, []);
  var startAutoSliding = useCallback(function () {
    clearTimeout(started.current.timeout);
    if (started.current.started) {
      started.current.timeout = setTimeout(function () {
        moveSlide('next', false);
        startAutoSliding();
      }, autoSlideDuration);
    }
  }, [started, moveSlide, autoSlideDuration]);
  useEffect(function () {
    if (isAutoStart && !started.current.started) {
      started.current.started = true;
      startAutoSliding();
    }
  }, [isAutoStart, startAutoSliding]);
  useEffect(function () {
    isAutoStartSet(isAutoSlide);
    if (!isAutoSlide) {
      started.current.started = false;
      clearTimeout(started.current.timeout);
    }
  }, [isAutoSlide]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("button", {
    onClick: function onClick() {
      return moveSlide('pre');
    },
    type: "button",
    className: styles.navBtn + " " + styles.prev,
    "aria-label": "Previous image",
    title: "Previous image"
  }), /*#__PURE__*/React.createElement("button", {
    onClick: function onClick() {
      return moveSlide('next');
    },
    type: "button",
    className: styles.navBtn + " " + styles.next,
    "aria-label": "Next image",
    title: "Next image"
  }));
};

var LoadSlider = function LoadSlider(props) {
  var styles = props.styles,
    _props$sliderIndex = props.sliderIndex,
    sliderIndex = _props$sliderIndex === void 0 ? 0 : _props$sliderIndex,
    _props$images = props.images,
    images = _props$images === void 0 ? [] : _props$images,
    imageSrcKey = props.imageSrcKey,
    imageAltKey = props.imageAltKey,
    slideAnimationDuration = props.slideAnimationDuration,
    objectFit = props.objectFit,
    imageBackgroundColor = props.imageBackgroundColor,
    isAutoSlide = props.isAutoSlide,
    autoSlideDuration = props.autoSlideDuration;
  var imageBlock = useRef();
  var screen = useRef();
  var _useState = useState({
      sliderIndex: sliderIndex,
      xCursor: 0,
      yCursor: 0,
      xImgEle: 0,
      yImgEle: 0
    }),
    data = _useState[0],
    setData = _useState[1];
  var transformImage = function transformImage(imgBlock, animation) {
    if (animation === void 0) {
      animation = true;
    }
    var width = imgBlock.clientWidth * data.sliderIndex + 1;
    imgBlock.style.transform = "translate3d(-" + (width - 1) + "px, 0px, 0px)";
    imgBlock.style['transition-duration'] = "" + (animation ? slideAnimationDuration : '0');
    setTimeout(function () {
      imgBlock.style['transition-duration'] = "0ms";
    }, 300);
  };
  useEffect(function () {
    screen.current.style['background-color'] = imageBackgroundColor;
  }, []);
  useEffect(function () {
    if (data.sliderIndex >= 0 && data.sliderIndex < images.length) {
      transformImage(imageBlock.current);
      setData(function (preState) {
        return _extends({}, preState, {
          zoomIndex: 0
        });
      });
      window.onresize = function () {
        transformImage(imageBlock.current, false);
      };
    } else {
      setData(function (preState) {
        return _extends({}, preState, {
          sliderIndex: 0
        });
      });
    }
    return function () {
      window.onresize = null;
    };
  }, [data.sliderIndex]);
  return /*#__PURE__*/React.createElement("div", {
    className: styles.Content,
    ref: screen
  }, /*#__PURE__*/React.createElement("div", {
    className: styles.customSlider
  }, images.length > 0 ? /*#__PURE__*/React.createElement("div", {
    className: styles.inner,
    ref: imageBlock
  }, images.map(function (img, index) {
    return /*#__PURE__*/React.createElement("div", {
      className: styles.image,
      key: index
    }, /*#__PURE__*/React.createElement("img", {
      src: imageSrcKey ? img[imageSrcKey] : img,
      alt: imageAltKey ? img[imageAltKey] : img,
      style: {
        objectFit: objectFit
      }
    }));
  })) : /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("h1", null, "Images not availabe!")), /*#__PURE__*/React.createElement(Slider, {
    styles: styles,
    imageBlock: imageBlock,
    sliderIndex: data.sliderIndex,
    zoomIndex: data.zoomIndex,
    setData: setData,
    isAutoSlide: isAutoSlide,
    autoSlideDuration: autoSlideDuration
  })));
};

var styles = {"Content":"_3eJOp","customSlider":"_2XMmq","inner":"_1oXyH","image":"_2hdkJ","prev":"_KqFRp","navBtn":"_3fMhj","next":"_1uQwZ"};

var ReactSlider = function ReactSlider(_ref) {
  var _ref$sliderIndex = _ref.sliderIndex,
    sliderIndex = _ref$sliderIndex === void 0 ? 0 : _ref$sliderIndex,
    _ref$images = _ref.images,
    images = _ref$images === void 0 ? [] : _ref$images,
    _ref$imageSrcKey = _ref.imageSrcKey,
    imageSrcKey = _ref$imageSrcKey === void 0 ? 'src' : _ref$imageSrcKey,
    _ref$imageAltKey = _ref.imageAltKey,
    imageAltKey = _ref$imageAltKey === void 0 ? 'src' : _ref$imageAltKey,
    _ref$slideAnimationDu = _ref.slideAnimationDuration,
    slideAnimationDuration = _ref$slideAnimationDu === void 0 ? '600ms' : _ref$slideAnimationDu,
    _ref$objectFit = _ref.objectFit,
    objectFit = _ref$objectFit === void 0 ? 'fill' : _ref$objectFit,
    _ref$imageBackgroundC = _ref.imageBackgroundColor,
    imageBackgroundColor = _ref$imageBackgroundC === void 0 ? 'rgba(0, 0, 0, 0.5)' : _ref$imageBackgroundC,
    _ref$isAutoSlide = _ref.isAutoSlide,
    isAutoSlide = _ref$isAutoSlide === void 0 ? false : _ref$isAutoSlide,
    _ref$autoSlideDuratio = _ref.autoSlideDuration,
    autoSlideDuration = _ref$autoSlideDuratio === void 0 ? 4000 : _ref$autoSlideDuratio;
  var loadSlider = useMemo(function () {
    return /*#__PURE__*/React.createElement(LoadSlider, {
      styles: styles,
      sliderIndex: sliderIndex,
      images: images,
      imageSrcKey: imageSrcKey,
      imageAltKey: imageAltKey,
      slideAnimationDuration: slideAnimationDuration,
      objectFit: objectFit,
      imageBackgroundColor: imageBackgroundColor,
      isAutoSlide: isAutoSlide,
      autoSlideDuration: autoSlideDuration
    });
  }, [isAutoSlide, autoSlideDuration]);
  return loadSlider;
};

export { ReactSlider };
//# sourceMappingURL=index.modern.js.map
